# math-series
Python package to calculate harmonic numbers

### Installing math-series
math-series supports Python 3+. The stable version of math-series is available on [PyPI](https://pypi.org/project/math-series/):

    pip install math-series
